<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="gl_ES">
<context>
    <name>DecoderFFapFactory</name>
    <message>
        <location filename="../decoderffapfactory.cpp" line="50"/>
        <source>FFap Plugin</source>
        <translation>Plugin FFap</translation>
    </message>
    <message>
        <location filename="../decoderffapfactory.cpp" line="52"/>
        <source>Monkey&apos;s Audio Files</source>
        <translation>Arquivos de audio Monkey</translation>
    </message>
    <message>
        <location filename="../decoderffapfactory.cpp" line="156"/>
        <source>About FFap Audio Plugin</source>
        <translation>Acerca do plugin de audio FFap</translation>
    </message>
    <message>
        <location filename="../decoderffapfactory.cpp" line="157"/>
        <source>Qmmp FFap Audio Plugin</source>
        <translation>Plugin de aduio Qmmp FFap</translation>
    </message>
    <message>
        <location filename="../decoderffapfactory.cpp" line="158"/>
        <source>This plugin provides Monkey&apos;s Audio (APE) support</source>
        <translation>Este plugin proporciona soporte para Monkey&apos;s Audio (APE)</translation>
    </message>
    <message>
        <location filename="../decoderffapfactory.cpp" line="159"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>Escrito por: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
    <message>
        <location filename="../decoderffapfactory.cpp" line="160"/>
        <source>Based on code from deadbeef, FFmpeg and rockbox</source>
        <translation>Basado no código de deadbeef, FFmpeg e rockbox</translation>
    </message>
</context>
<context>
    <name>FFapMetaDataModel</name>
    <message>
        <location filename="../ffapmetadatamodel.cpp" line="60"/>
        <source>Length</source>
        <translation>Lonxitude</translation>
    </message>
    <message>
        <location filename="../ffapmetadatamodel.cpp" line="61"/>
        <source>Sample rate</source>
        <translation>Frecuencia de mostra</translation>
    </message>
    <message>
        <location filename="../ffapmetadatamodel.cpp" line="61"/>
        <source>Hz</source>
        <translation>Hz</translation>
    </message>
    <message>
        <location filename="../ffapmetadatamodel.cpp" line="62"/>
        <source>Channels</source>
        <translation>Canais</translation>
    </message>
    <message>
        <location filename="../ffapmetadatamodel.cpp" line="63"/>
        <source>Bitrate</source>
        <translation>Taxa de bits</translation>
    </message>
    <message>
        <location filename="../ffapmetadatamodel.cpp" line="63"/>
        <source>kbps</source>
        <translation>kbps</translation>
    </message>
    <message>
        <location filename="../ffapmetadatamodel.cpp" line="64"/>
        <source>File size</source>
        <translation>Tamaño do ficheiro</translation>
    </message>
    <message>
        <location filename="../ffapmetadatamodel.cpp" line="64"/>
        <source>KB</source>
        <translation>KB</translation>
    </message>
</context>
</TS>
